package javax.swing;

import javax.accessibility.AccessibleRole;
import javax.accessibility.AccessibleContext;
import java.io.ObjectInputStream;
import java.io.IOException;
import java.io.ObjectOutputStream;
import javax.swing.plaf.ButtonUI;
import javax.accessibility.Accessible;

public class JCheckBox extends JToggleButton implements Accessible
{
    public static final String BORDER_PAINTED_FLAT_CHANGED_PROPERTY = "borderPaintedFlat";
    private boolean flat;
    private static final String uiClassID = "CheckBoxUI";
    
    public JCheckBox() {
        this(null, null, false);
    }
    
    public JCheckBox(Icon icon) {
        this(null, icon, false);
    }
    
    public JCheckBox(Icon icon, boolean b) {
        this(null, icon, b);
    }
    
    public JCheckBox(String s) {
        this(s, null, false);
    }
    
    public JCheckBox(Action action) {
        this();
        this.setAction(action);
    }
    
    public JCheckBox(String s, boolean b) {
        this(s, null, b);
    }
    
    public JCheckBox(String s, Icon icon) {
        this(s, icon, false);
    }
    
    public JCheckBox(String s, Icon icon, boolean b) {
        super(s, icon, b);
        this.flat = false;
        this.setUIProperty("borderPainted", Boolean.FALSE);
        this.setHorizontalAlignment(10);
    }
    
    public void setBorderPaintedFlat(boolean flat) {
        int flat2 = this.flat;
        this.firePropertyChange("borderPaintedFlat", (boolean)flat2, this.flat = flat);
        if ((flat ? 1 : 0) != flat2) {
            this.revalidate();
            this.repaint();
        }
    }
    
    public boolean isBorderPaintedFlat() {
        return this.flat;
    }
    
    @Override
    public void updateUI() {
        this.setUI((ButtonUI)UIManager.getUI(this));
    }
    
    @Override
    public String getUIClassID() {
        return "CheckBoxUI";
    }
    
    @Override
    void setIconFromAction(Action action) {
    }
    
    private void writeObject(ObjectOutputStream objectOutputStream) throws IOException {
        objectOutputStream.defaultWriteObject();
        if (this.getUIClassID().equals("CheckBoxUI")) {
            int n = (byte)(JComponent.getWriteObjCounter(this) - 1);
            JComponent.setWriteObjCounter(this, (byte)n);
            if (n == 0 && this.ui != null) {
                this.ui.installUI(this);
            }
        }
    }
    
    private void readObject(ObjectInputStream objectInputStream) throws IOException, ClassNotFoundException {
        objectInputStream.defaultReadObject();
        if (this.getUIClassID().equals("CheckBoxUI")) {
            this.updateUI();
        }
    }
    
    @Override
    protected String paramString() {
        return super.paramString();
    }
    
    @Override
    public AccessibleContext getAccessibleContext() {
        if (this.accessibleContext == null) {
            this.accessibleContext = new JCheckBox.AccessibleJCheckBox();
        }
        return this.accessibleContext;
    }
    
    protected class AccessibleJCheckBox extends JToggleButton.AccessibleJToggleButton
    {
        @Override
        public AccessibleRole getAccessibleRole() {
            return AccessibleRole.CHECK_BOX;
        }
    }
}
